# Coscine Python Client

### Coscine

![img](data/logo.png)

Coscine is an integration platform for research data hosted at RWTH Aachen University.
Visit [Landing Page] for more information.

### About

This library provides a simple to use Python3 client for the Coscine REST API.

### Installation

Ensure you have Python3 and pip3 installed. As this is platform
dependent, you need to figure out how to install them by yourself.
This will get you started:
- [https://wiki.python.org/moin/BeginnersGuide](https://wiki.python.org/moin/BeginnersGuide)
- [https://www.python.org/downloads/](https://www.python.org/downloads/)

This project is hosted on the Python Package Index (PyPi). You can
install it and all of its dependencies via the python package manager (pip):
```sh
python -m pip install --user coscine
```

### Documentation

Documentation can be found [here](DOCUMENTATION.md).

### Contact

To report bugs, request features or resolve questions open an issue inside
of the current git repository.

To contribute code and help improve this package fork the repository and
open a merge request.

For general help or consulting contact RWTH Aachen
IT ServiceDesk at <servicedesk@rwth-aachen.de>.

### License

This project is Open Source Software and licensed
under the terms of the MIT License.
```
The MIT License (MIT)
Copyright © 2021 RWTH Aachen University

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
the Software, and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
```